globals [
  current_time                                                   ;; tracks current time period
  tech_highest_scope
  tech_highest_quality
  tech_highest_cost
  tech_highest_time
  tech_average_scope
  tech_average_quality
  tech_average_cost
  tech_average_time

;;  tech_allowable_entres_max

  highest_offered_scope
  highest_offered_quality
  highest_offered_cost
  highest_offered_time
  highest_value_chain_count

  market_share_first_mover
  market_share_ambidex
  market_share_fast_follower
  avr_age_first_mover
  avr_age_ambidex
  avr_age_fast_follower
  dead_count_first_mover
  dead_count_ambidex
  dead_count_fast_follower
  born_count_first_mover
  born_count_ambidex
  born_count_fast_follower

  entre_link_freq
  entre_allowable_techs_max
  consumer_link_freq
  consumer_allowable_entre_max
  dead_entre_age_list

  temp_var_0
  temp_var_1
  temp_var_2
  temp_var_3
]

breed [techs tech]
breed [entres entre]
breed [consumers consumer]
undirected-link-breed [b2b_links b2b_link]
undirected-link-breed [b2c_links b2c_link]
directed-link-breed [tech_links tech_link]


techs-own [
  tech_type_id
  region_id
  tech_max
  tech_selected_time
  count_of_connected_b2b_via_entre
  count_of_connected_b2c_via_entre
  tech_develop_time_duration
  tech_develop_increment
  tech_unused_count
  scope_max
  time_max
  cost_max
  quality_max
  quality
  scope
  time
  cost
  allowable_entres
  ]

entres-own [
  entre_type_id
  region_id
  allowable_techs
  activity_range
  age
  market_share
  entre_unselected_count
  scope_sensitivity
  time_sensitivity
  quality_sensitivity
  cost_sensitivity
  offered_scope
  offered_quality
  offered_cost
  ]

consumers-own [
  consumer_type_id
  region_id
  population
  scope_preference
  cost_preference                                                     ;; amount of profit gathered made from the market
  quality_preference                                                   ;; unique imitator-id
  change_resistance                                                            ;; activity range per tick
  ]

b2b_links-own [
  weight
  ]

b2c_links-own [
  weight
  ]

tech_links-own [
  weight
  ]


;; ---------------------------------------------------------
;; STARTUP - auto-setup when the model is opened
;; ---------------------------------------------------------
to startup

  clear-all

  init-globals

  create-techs num_techs [
    set tech_max 100
    set shape "square 2"
    tech-parameter-set
  ]

  create-entres num_entres [
    set activity_range 1
    entre-parameter-set

  ]

  create-consumers num_consumers [
    set size 0.8
    set population 1
    consumer-parameter-set
  ]

end



to init-globals

  set current_time 0
  set entre_link_freq 100
  set consumer_link_freq 100
  set consumer_allowable_entre_max 1

  (ifelse
  (num_regions = 2) [
      ask patches with [ pxcor <= 0 ] [set pcolor 0]
      ask patches with [ pxcor > 0 ] [set pcolor 32]
   ]
  (num_regions = 3) [
      ask patches with [ pxcor <= min-pxcor * 0.33 ] [set pcolor 0]
      ask patches with [ ( pxcor > min-pxcor * 0.33 ) and ( pxcor <= max-pxcor * 0.33 ) ] [set pcolor 32]
      ask patches with [ pxcor > max-pxcor * 0.33 ] [set pcolor 62]
   ]
  (num_regions = 4) [
      ask patches with [ pxcor <= min-pxcor * 0.5 ] [set pcolor 0]
      ask patches with [ ( pxcor > min-pxcor * 0.5 ) and ( pxcor <= 0 ) ] [set pcolor 32]
      ask patches with [ ( pxcor > 0 ) and ( pxcor <= max-pxcor * 0.5 ) ] [set pcolor 62]
      ask patches with [ pxcor > max-pxcor * 0.5 ] [set pcolor 92]
   ] [ ] )

  set temp_var_0 0
  set temp_var_1 0
  set temp_var_2 0
  set temp_var_3 0

  ;;  set tech_allowable_entres_max 3


end


to tech-parameter-set

  setxy random-pxcor (max-pycor * 0.6 + random-pycor * 0.25)
  region-parameter-set

    set color 97
    set size 1
    set allowable_entres ( random tech_allowable_entres_max + 1 )

    let choice random 6
    (ifelse
      choice = 0 [
       set scope_max random ( tech_max )
       set time_max random ( tech_max )
       set cost_max (tech_max - scope_max)
       set quality_max (tech_max - time_max)
      ]
      choice = 1 [
       set scope_max random ( tech_max )
       set time_max random ( tech_max )
       set cost_max (tech_max - time_max)
       set quality_max (tech_max - scope_max)
      ]
      choice = 2 [
       set scope_max random ( tech_max )
       set cost_max random ( tech_max )
       set time_max (tech_max - scope_max)
       set quality_max (tech_max - cost_max)
      ]
      choice = 3 [
       set scope_max random ( tech_max )
       set cost_max random ( tech_max )
       set time_max (tech_max - cost_max)
       set quality_max (tech_max - scope_max)      ]
      choice = 4 [
       set scope_max random ( tech_max )
       set quality_max random ( tech_max )
       set cost_max (tech_max - scope_max)
       set time_max (tech_max - quality_max)
      ]
     ; elsecommands
      [
       set scope_max random ( tech_max )
       set quality_max random ( tech_max )
       set cost_max (tech_max - quality_max)
       set time_max (tech_max - scope_max)
    ])

    set scope ( random (int scope_max) + 1 )
    set cost ( random (int cost_max) + 1 )
    set quality ( random (int quality_max) + 1 )
    set time ( random (int time_max) + 1 )

end


to entre-parameter-set                                                         ;; 1. First Mover 2, Ambidex 3, Fast Follower

    setxy random-pxcor (random-pycor * 0.1)
    set size 1
    region-parameter-set

    let choice random 9
    (ifelse
      choice < 3 [
       set shape "person"
       set color green
       set entre_type_id 1
       set scope_sensitivity 90
       set time_sensitivity 90
       set cost_sensitivity 10
       set quality_sensitivity 10
       set allowable_techs ( random num_value_chain + 1 )
       set born_count_first_mover (born_count_first_mover + 1)
      ]
      choice < 6 [
       set shape "person"
       set color blue
       set entre_type_id 2
       set scope_sensitivity 50
       set time_sensitivity 50
       set cost_sensitivity 50
       set quality_sensitivity 50
       set allowable_techs ( random num_value_chain + 1 )
       set born_count_ambidex (born_count_ambidex + 1)

    ]
      ; elsecommands
      [
       set shape "person"
       set color red
       set entre_type_id 3
       set scope_sensitivity 10
       set time_sensitivity 10
       set cost_sensitivity 90
       set quality_sensitivity 90
       set allowable_techs ( random num_value_chain + 1 )
       set born_count_fast_follower (born_count_fast_follower + 1)
  ])

end


to  consumer-parameter-set

    setxy random-pxcor (min-pycor * 0.6 + random-pycor * 0.3)
    region-parameter-set

    let choice random 100
    (ifelse
      choice < 3 [                                                  ;; Pioneer/Innovator 2.5
       set shape "face happy"
       set color green
       set consumer_type_id 1
       set scope_preference 90
       set cost_preference 10
       set quality_preference 50
       set change_resistance 10
      ]
      choice < 16 [                                                ;; Early Adaptor 13.5,
       set shape "face happy"
       set color blue
       set consumer_type_id 2
       set scope_preference 70
       set cost_preference 10
       set quality_preference 70
       set change_resistance 20
      ]
      choice < 50 [                                                ;; Early Major 34
       set shape "face neutral"
       set color yellow
       set consumer_type_id 3
       set scope_preference 60
       set cost_preference 30
       set quality_preference 60
      if ( chasm = "off" ) [ set change_resistance 30 ]
      if ( chasm = "on" ) [ set change_resistance 80 ]
      ]
      choice < 84 [                                                ;; Late Major 34
       set shape "face neutral"
       set color orange
       set consumer_type_id 4
       set scope_preference 10
       set cost_preference 70
       set quality_preference 70
      if ( chasm = "off" ) [ set change_resistance 50 ]
      if ( chasm = "on" ) [ set change_resistance 90 ]
      ]
      ; elsecommands
      [                                                           ;;  Laddgards 16
       set shape "face sad"
       set color red
       set consumer_type_id 5
       set scope_preference 10
       set cost_preference 90
       set quality_preference 50
      if ( chasm = "off" ) [ set change_resistance 80 ]
      if ( chasm = "on" ) [ set change_resistance 95 ]
      ])

end

to region-parameter-set

  (ifelse
  (num_regions = 1) [
     set region_id 1
   ]
   (num_regions = 2) [
      if ( xcor <= 0 ) [ set region_id 1 ]
      if ( xcor > 0 ) [ set region_id 2 ]
   ]
   (num_regions = 3) [
      if ( xcor <= min-pxcor * 0.33 ) [ set region_id 1 ]
      if ( xcor > min-pxcor * 0.33 ) and ( xcor <= max-pxcor * 0.33 ) [ set region_id 2 ]
      if ( xcor > max-pxcor * 0.33 ) [ set region_id 3 ]
   ]
  (num_regions = 4) [
      if ( xcor <= min-pxcor * 0.5 ) [ set region_id 1 ]
      if ( ( xcor > min-pxcor * 0.5 ) and ( pxcor <= 0 ) ) [ set region_id 2 ]
      if ( ( xcor > 0 ) and ( xcor <= max-pxcor * 0.5 ) ) [ set region_id 3 ]
      if ( xcor > max-pxcor * 0.5 ) [ set region_id 4 ]
   ] [ ] )

end


;; ---------------------------------------------------------
;; RUN THE SIMULATION
;; ---------------------------------------------------------
to run-sim

  tech-evolves
  entre-builds
  consumer-selects
  plot-result

  set current_time ( current_time + 1 )
  if ( current_time >= Time_Duration ) [display user-message "Time out" stop]

end


to tech-evolves

  ask techs with [ count my-out-b2b_links > 0 ]
  [
     set label count my-b2b_links

    ( if ( ( tech_selected_time = 0 ) and ( count my-out-b2b_links > 0 ) ) [
      set tech_selected_time current_time
      set tech_develop_time_duration time ] )

    ( ifelse
      ( ( [ count my-out-b2b_links ] of max-one-of entres with [ out-b2b_link-neighbor? myself ] [ count my-out-b2b_links ] ) = 0 )
      [ set count_of_connected_b2b_via_entre 0 ]
      [ set count_of_connected_b2b_via_entre ( [ count my-out-b2b_links ] of max-one-of entres with [ out-b2b_link-neighbor? myself ] [ count my-out-b2b_links ] ) ] )

    ( ifelse
      ( ( [ count my-out-b2b_links ] of max-one-of entres with [ out-b2b_link-neighbor? myself ] [ count my-out-b2c_links ] ) = 0 )
      [ set count_of_connected_b2c_via_entre 0 ]
      [ set count_of_connected_b2c_via_entre ( [ count my-out-b2c_links ] of max-one-of entres with [ out-b2b_link-neighbor? myself ] [ count my-out-b2c_links ] ) ] )

    ( if ( ( current_time - tech_selected_time ) <= tech_develop_time_duration )
    [
    set scope ( scope + ( count_of_connected_b2b_via_entre / ( num_value_chain * num_entres) * sustaining_tech_develop_speed ) )
    set cost ( cost + ( count_of_connected_b2c_via_entre / num_consumers * sustaining_tech_develop_speed ) )
    set quality ( quality + ( count_of_connected_b2c_via_entre / num_consumers * sustaining_tech_develop_speed ) )
    ] )
  ]

;; sigmoid function
;; 1 / ( 1 + e ^ ( - -6 ) )  =  0.002472623156634775
;; 1 / ( 1 + e ^ ( - 6 ) )  =  0.9975273768433653

  ask techs with [count my-out-b2b_links = 0 ] [
    set tech_unused_count (tech_unused_count + 1)
    if tech_unused_count > 10 [
      hatch 1 [
        set tech_max ( tech_max + disruptive_tech_develop_speed )
        set tech_unused_count 0
        tech-parameter-set ]
      die ]
    ]

end


to entre-builds

  if ( any? entres with [ entre_type_id = 1 ] ) [ ask one-of entres with [ entre_type_id = 1 ] [ if (count my-out-b2b_links <= allowable_techs) [ explore-b2b_link ] ] ]
  if ( any? entres with [ entre_type_id = 2 ] ) [ ask one-of entres with [ entre_type_id = 2 ] [ if (count my-out-b2b_links <= allowable_techs) [ explore-b2b_link ] ] ]
  if ( any? entres with [ entre_type_id = 3 ] ) [ ask one-of entres with [ entre_type_id = 3 ] [ if (count my-out-b2b_links <= allowable_techs) [ explore-b2b_link ] ] ]

  ;;layout-spring (techs with [count out-b2b_link-neighbors >= 1]) links 0.4 1 1
  ;;layout-tutte (techs with [count out-b2b_link-neighbors >= 1]) links 4
  ;;layout-spring (techs with [count out-b2b_link-neighbors >= 1]) links 0.4 1 1

  ask entres
  [
    set label count my-b2b_links

    set market_share count my-b2c_links
    ( ifelse
    ( market_share > num_consumers * 0.1 ) [ set size 2.0 ]
    ( market_share > num_consumers * 0.2 ) [ set size 3.0 ]
    ( market_share > num_consumers * 0.5 ) [ set size 4.0 ] [  ] )

    set age ( age + 1)
    set offered_scope ( sum [ scope ] of techs with [ in-b2b_link-neighbor? myself ] )
    set offered_cost ( sum [ cost ] of techs with [ in-b2b_link-neighbor? myself ] )
    set offered_quality ( sum [ quality ] of techs with [ in-b2b_link-neighbor? myself ] )

  ]

  ask entres with [ market_share = 0]
  [
    set entre_unselected_count (entre_unselected_count + 1)
    if entre_unselected_count > entre_survival_duration [
       hatch 1 [
        entre-parameter-set
        set entre_unselected_count 0
        set offered_scope 0
        set offered_cost 0
        set offered_quality 0
        set age 0
        set market_share 0
      ]
        if entre_type_id = 1 [ set dead_count_first_mover (dead_count_first_mover + 1) ]
        if entre_type_id = 2 [ set dead_count_ambidex (dead_count_ambidex + 1) ]
        if entre_type_id = 3 [ set dead_count_fast_follower (dead_count_fast_follower + 1) ]
      die
   ]
  ]


end

to explore-b2b_link

  if ( count techs with [ (count my-out-b2b_links < allowable_entres) and ( region_id = [ region_id ] of myself) ] > 0 )
    [ let freq0 random entre_link_freq
      ( if freq0 < time_sensitivity
        [ let choice random ( scope_sensitivity + cost_sensitivity + quality_sensitivity + 1 )
          ( ifelse
            ( ( 0 <= choice ) and ( choice < scope_sensitivity ) )
            [ let freq1 random entre_link_freq
              ( if ( freq1 < scope_sensitivity )
              [ let reg_random random 100
                 ( ifelse ( reg_random > regional_barrier_on_b2b )
                  [ set temp_var_0 ( [ who ] of max-one-of techs with [ count my-out-b2b_links < allowable_entres ] [scope] ) ]
                  [ set temp_var_0 ( [ who ] of max-one-of techs with [ (count my-out-b2b_links < allowable_entres) and ( region_id = [ region_id ] of myself) ] [scope] ) ] )
                create-b2b_link-with one-of techs with [ who = temp_var_0 ] [set color 94 set weight 1 ] ] ) ]

            ( ( scope_sensitivity <= choice ) and ( choice < (scope_sensitivity + cost_sensitivity) ) )
            [ let freq2 random entre_link_freq
              (if ( freq2 < cost_sensitivity )
              [ let reg_random random 100
                ( ifelse ( reg_random > regional_barrier_on_b2b )
                  [ set temp_var_1 ( [ who ] of max-one-of techs with [ count my-out-b2b_links < allowable_entres ] [cost] ) ]
                  [ set temp_var_1 ( [ who ] of max-one-of techs with [ (count my-out-b2b_links < allowable_entres) and ( region_id = [ region_id ] of myself) ] [cost] ) ] )
               create-b2b_link-with one-of techs with [ who = temp_var_1 ] [set color 94 set weight 1 ] ] ) ]

            ;;else
           [ let freq3 random entre_link_freq
              ( if ( freq3 < quality_sensitivity )
              [ let reg_random random 100
                  ( ifelse ( reg_random > regional_barrier_on_b2b )
                    [ set temp_var_2 ( [ who ] of max-one-of techs with [ count my-out-b2b_links < allowable_entres ] [quality] ) ]
                    [ set temp_var_2 ( [ who ] of max-one-of techs with [ (count my-out-b2b_links < allowable_entres) and ( region_id = [ region_id ] of myself) ] [quality] ) ] )
               create-b2b_link-with one-of techs with [ who = temp_var_2 ] [set color 94 set weight 1 ] ] ) ]
          ) ] ) ]

  set temp_var_0 0
  set temp_var_1 0
  set temp_var_2 0

end


to consumer-selects

  ask one-of consumers with [ consumer_type_id = 1 ] [ explore-b2c_link ]
  ask one-of consumers with [ consumer_type_id = 2 ] [ explore-b2c_link ]
  ask one-of consumers with [ consumer_type_id = 3 ] [ explore-b2c_link ]
  ask one-of consumers with [ consumer_type_id = 4 ] [ explore-b2c_link ]
  ask one-of consumers with [ consumer_type_id = 5 ] [ explore-b2c_link ]

end


to explore-b2c_link

    if ( count my-out-b2c_links >= consumer_allowable_entre_max) [
     let freq0 random consumer_link_freq (ifelse freq0 > change_resistance [
      ask my-out-b2c_links [die]
     ] [ ])
    ]

    if (count my-out-b2c_links < consumer_allowable_entre_max) [
    let choice random ( scope_preference + cost_preference + quality_preference + 1 )
    (ifelse
      (( 0 <= choice ) and ( choice < scope_preference ) )
      [ let reg_random random 100
        ( ifelse ( reg_random > regional_barrier_on_b2c )
        [ set temp_var_0 ( [ who ] of max-one-of entres [offered_scope] ) ]
        [ set temp_var_0 ( [ who ] of max-one-of entres with [ region_id = [ region_id ] of myself ] [offered_scope] ) ] )
       create-b2c_link-with one-of entres with [ who = temp_var_0 ] [set color 3 set weight 1 ] ]

      ( ( scope_preference <= choice ) and (choice < (scope_preference + cost_preference ) ) )
       [ let reg_random random 100
        ( ifelse ( reg_random > regional_barrier_on_b2c )
        [ set temp_var_1 ( [ who ] of max-one-of entres [offered_cost] ) ]
        [ set temp_var_1 ( [ who ] of max-one-of entres with [ region_id = [ region_id ] of myself ] [offered_cost] ) ] )
       create-b2c_link-with one-of entres with [ who = temp_var_1 ] [set color 3 set weight 1 ] ]

     ;;else
       [ let reg_random random 100
        ( ifelse ( reg_random > regional_barrier_on_b2c )
        [ set temp_var_2 ( [ who ] of max-one-of entres [offered_quality] ) ]
        [ set temp_var_2 ( [ who ] of max-one-of entres with [ region_id = [ region_id ] of myself ] [offered_quality] ) ] )
       create-b2c_link-with one-of entres with [ who = temp_var_2 ] [set color 3 set weight 1 ] ]
     ) ]

end


to plot-result

;; set tech_average_scope ( mean [ scope ] of techs )
;; set tech_average_cost ( mean [ cost ] of techs )
;; set tech_average_quality ( mean [ quality ] of techs )
;; set tech_average_time ( mean [ time ] of techs )
;; set tech_highest_scope ( max [ scope ] of techs )
;; set tech_highest_cost ( max [ cost ] of techs )
;; set tech_highest_quality ( max [ quality ] of techs )
;; set tech_highest_time ( max [ time ] of techs )
;; set-current-plot "Tech Indicator"
;; set-current-plot-pen "Average S" plot tech_average_scope
;; set-current-plot-pen "Average T" plot tech_average_time
;; set-current-plot-pen "Average C" plot tech_average_cost
;; set-current-plot-pen "Average Q" plot tech_average_quality
;; set-current-plot-pen "Highest T" plot tech_highest_time
;; set-current-plot-pen "Highest S" plot tech_highest_scope
;; set-current-plot-pen "Highest C" plot tech_highest_cost
;; set-current-plot-pen "Highest Q" plot tech_highest_quality

;; set highest_offered_scope ( max [ offered_scope ] of entres )
;; set highest_offered_quality ( max [ offered_quality ] of entres )
;; set highest_offered_cost ( max [ offered_cost ] of entres )
;; set highest_value_chain_count ( max [ count my-out-b2b_links ] of entres  )
;; set-current-plot "Offered Solution Indicator"
;; set-current-plot-pen "Highest S" plot highest_offered_scope
;; set-current-plot-pen "Highest C" plot highest_offered_cost
;; set-current-plot-pen "Highest Q" plot highest_offered_quality

 if ( any? entres with [ entre_type_id = 1 ] ) [ set market_share_first_mover ( sum [ count my-out-b2c_links ] of entres with [ entre_type_id = 1 ] ) ]
 if ( any? entres with [ entre_type_id = 2 ] ) [ set market_share_ambidex ( sum [ count my-out-b2c_links ]of entres with [ entre_type_id = 2 ] ) ]
 if ( any? entres with [ entre_type_id = 3 ] ) [ set market_share_fast_follower ( sum [ count my-out-b2c_links ] of entres with [ entre_type_id = 3 ] ) ]
 set-current-plot "Market Share Indicator"
 set-current-plot-pen "MS First Mover" plot market_share_first_mover
 set-current-plot-pen "MS Ambidex" plot market_share_ambidex
 set-current-plot-pen "MS Fast Follower" plot market_share_fast_follower

 if ( any? entres with [ entre_type_id = 1 ] ) [ set avr_age_first_mover ( mean [ age ] of entres with [ entre_type_id = 1 ] ) ]
 if ( any? entres with [ entre_type_id = 2 ] ) [ set avr_age_ambidex ( mean [ age ] of entres with [ entre_type_id = 2 ] ) ]
 if ( any? entres with [ entre_type_id = 3 ] ) [ set avr_age_fast_follower ( mean [ age ] of entres with [ entre_type_id = 3 ] ) ]
;; set-current-plot "Entre Avr Age Indicator"
;; set-current-plot-pen "AA First Mover" plot avr_age_first_mover
;; set-current-plot-pen "AA Ambidex" plot avr_age_ambidex
;; set-current-plot-pen "AA Fast Follower" plot avr_age_fast_follower


;;  set total_market_count ( count market_links )
;;  set-current-plot "Total Market Count"
;;  set-current-plot-pen "Total Market Count"
;;  plot total_market_count

;;  set average_market_amount ( mean [ market_amount ] of markets )
;;  set-current-plot "Average Market Amount"
;;  set-current-plot-pen "Average Market Amount"
;;  plot average_market_amount


end


;;----------------------------------------------------
;; commonly used command line
;;----------------------------------------------------

;; show sort [who] of techs with [quality > 600]
;; show sort [who] of techs
;; show [cost] of tech 51584
;; show [time] of tech 51584
;; show [scope] of tech 51584
;; show [quality] of tech 51584

;;ask consumers with [xcor > 0 ] [ create-links-with entres with [xcor > 0 ]]

;;ask tech 0 [create-link-with tech 2]
@#$#@#$#@
GRAPHICS-WINDOW
244
10
785
552
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-20
20
-20
20
0
0
1
ticks
30.0

SLIDER
1
45
232
78
num_entres
num_entres
0
100
40.0
10
1
NIL
HORIZONTAL

SLIDER
1
81
233
114
num_consumers
num_consumers
0
1000
1000.0
20
1
NIL
HORIZONTAL

SLIDER
1
8
231
41
num_techs
num_techs
10
300
210.0
10
1
NIL
HORIZONTAL

BUTTON
11
516
119
549
Setup
startup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
787
12
1490
462
Market Share Indicator
NIL
NIL
0.0
3000.0
0.0
0.0
true
true
"" ""
PENS
"MS First Mover" 1.0 0 -13840069 true "" "plot market_share_first_mover"
"MS Ambidex" 1.0 0 -13791810 true "" "plot market_share_ambidex"
"MS Fast Follower" 1.0 0 -2674135 true "" "plot market_share_fast_follower"

BUTTON
129
517
236
550
Run
run-sim
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
0
192
235
225
tech_allowable_entres_max
tech_allowable_entres_max
1
30
5.0
1
1
NIL
HORIZONTAL

SLIDER
2
230
235
263
disruptive_tech_develop_speed
disruptive_tech_develop_speed
0.1
10
10.0
0.1
1
NIL
HORIZONTAL

SLIDER
1
268
235
301
sustaining_tech_develop_speed
sustaining_tech_develop_speed
0.01
2.5
0.96
0.01
1
NIL
HORIZONTAL

SLIDER
1
119
234
152
num_regions
num_regions
1
4
4.0
1
1
NIL
HORIZONTAL

SLIDER
2
305
237
338
regional_barrier_on_b2b
regional_barrier_on_b2b
0
100
6.0
1
1
NIL
HORIZONTAL

SLIDER
2
340
238
373
regional_barrier_on_b2c
regional_barrier_on_b2c
0
100
5.0
1
1
NIL
HORIZONTAL

SLIDER
2
156
234
189
num_value_chain
num_value_chain
1
10
3.0
1
1
NIL
HORIZONTAL

SLIDER
2
467
238
500
Time_Duration
Time_Duration
1000
100000
100000.0
100
1
NIL
HORIZONTAL

CHOOSER
4
416
237
461
chasm
chasm
"off" "on"
1

SLIDER
0
376
237
409
entre_survival_duration
entre_survival_duration
0
100
0.0
10
1
NIL
HORIZONTAL

MONITOR
791
470
958
515
born_count_first_mover
born_count_first_mover
17
1
11

MONITOR
963
470
1116
515
born_count_ambidex
born_count_ambidex
17
1
11

MONITOR
1123
470
1298
515
born_count_fast_follower
born_count_fast_follower
17
1
11

MONITOR
791
518
958
563
dead_count_first_mover
dead_count_first_mover
17
1
11

MONITOR
963
518
1118
563
dead_count_ambidex
dead_count_ambidex
17
1
11

MONITOR
1124
518
1303
563
dead_count_fast_follower
dead_count_fast_follower
17
1
11

@#$#@#$#@
## WHAT IS IT?

This model is developed to perform simulation on the study of the optimal business strategy by the interaction between new technologies and consumers. 

## HOW IT WORKS

This model consists of three agents, and each agent type operates per business theories as below.

Tech(New technologies): It evolves per sustaining or disruptive technology trajectory with the constraint of project triangle (scope, time, quality, and cost).
Entre(Entrepreneurs): It builds up tge solution by combining Tech components per its own strategy (exploration, exploitation, or ambidex).
Consumer(Consumer): It selects the solution per its own preference due to Diffusion of innovation theory.


## HOW TO USE IT

Set the number of agents. Tech, Entre, Consumer. 
Set the other environmental parameters. 
Click Setup and Run to play

## THINGS TO NOTICE

(N/A)

## THINGS TO TRY

The user can perform the simulation on which strategy would be the best per different environment of development speed and the appropriability of technologies.
The user can perform the simulation on how each envrionmental parameter changes are correlated to the others.

## EXTENDING THE MODEL

## NETLOGO FEATURES

## RELATED MODELS

## CREDITS AND REFERENCES

This netlogo model is developed from the scratch based on sevearl business theories. This model can be free to use, and I hope the updated/modified codes would be also free to use for other academic purpose. (sej.yoo@gmail.com) 
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
